@@ -3,16 +3,14 @@ from copy import deepcopy
 
 from django.contrib import admin
 
-from mezzanine.blog.models import BlogPost, BlogCategory, Comment
+from mezzanine.blog.models import BlogPost, BlogCategory
 from mezzanine.conf import settings
 from mezzanine.core.admin import DisplayableAdmin, OwnableAdmin
 
 
 blogpost_fieldsets = deepcopy(DisplayableAdmin.fieldsets)
-blogpost_fieldsets[0][1]["fields"].insert(1, "category")
+blogpost_fieldsets[0][1]["fields"].insert(1, "categories")
 blogpost_fieldsets[0][1]["fields"].append("content")
-blogpost_radio_fields = deepcopy(DisplayableAdmin.radio_fields)
-blogpost_radio_fields["category"] = admin.HORIZONTAL
 
 
 class BlogPostAdmin(DisplayableAdmin, OwnableAdmin):
@@ -22,7 +20,7 @@ class BlogPostAdmin(DisplayableAdmin, OwnableAdmin):
 
     fieldsets = blogpost_fieldsets
     list_display = ("title", "user", "status", "admin_link")
-    radio_fields = blogpost_radio_fields
+    filter_horizontal = ("categories",)
 
     def save_form(self, request, form, change):
         """
@@ -50,25 +48,5 @@ class BlogCategoryAdmin(admin.ModelAdmin):
         return False
 
 
-class CommentAdmin(admin.ModelAdmin):
-    """
-    Admin class for blog comments.
-    """
-
-    list_display = ("avatar_link", "intro", "time_created", "approved",
-        "blog_post", "admin_link")
-    list_display_links = ("intro", "time_created")
-    list_editable = ("approved",)
-    list_filter = ("blog_post", "approved", "name")
-    search_fields = ("name", "email", "body")
-    date_hierarchy = "time_created"
-    ordering = ("-time_created",)
-    fieldsets = (
-        (None, {"fields": (("name", "email", "website"), "body",
-            ("ip_address", "approved"), ("blog_post", "replied_to"))}),
-    )
-
 admin.site.register(BlogPost, BlogPostAdmin)
 admin.site.register(BlogCategory, BlogCategoryAdmin)
-if not settings.COMMENTS_DISQUS_SHORTNAME:
-    admin.site.register(Comment, CommentAdmin)
