@@ -3,12 +3,18 @@ from django.conf.urls.defaults import *
 
 from mezzanine.blog.feeds import PostsRSS, PostsAtom
 
+try:
+    # Django <= 1.3
+    from django.contrib.syndication.views import feed
+except ImportError:
+    # Django >= 1.4
+    feed = lambda request, url, **kwargs: kwargs[url]()(request)
+
 
 # Blog feed patterns.
 blog_feed_dict = {"rss": PostsRSS, "atom": PostsAtom}
 urlpatterns = patterns("",
-    url("^feeds/(?P<url>.*)/$", "django.contrib.syndication.views.feed",
-        {"feed_dict": blog_feed_dict}, name="blog_post_feed"),
+    url("^feeds/(?P<url>.*)/$", feed, blog_feed_dict, name="blog_post_feed"),
 )
 
 # Blog patterns.
